@@ -248,7 +248,7 @@ def root():
 @root.command()
 @click.option('-k', '--api-key', type=str)
 @click.option('-s', '--source', type=str)
-@click.argument('-t', '--target', type=str)
+@click.option('-t', '--target', type=str)
 def config(api_key, source, target):
     global configs
     """Show and set configuration"""
